==> neo4j-cypher-dsl-2021.2.3-sources.jar: org/neo4j/cypherdsl/core/Delete.java <==
/*
 * Copyright (c) 2019-2021 "Neo4j,"
 * Neo4j Sweden AB [https://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.neo4j.cypherdsl.core;

import static org.apiguardian.api.API.Status.EXPERIMENTAL;
import static org.apiguardian.api.API.Status.INTERNAL;

import org.apiguardian.api.API;
import org.neo4j.cypherdsl.core.ast.Visitor;

/**
 * See <a href="https://s3.amazonaws.com/artifacts.opencypher.org/M15/railroad/Delete.html">Delete</a>.
 *
 * @author Michael J. Simons
 * @since 1.0
 */
@API(status = EXPERIMENTAL, since = "1.0")
public final class Delete implements UpdatingClause {

	private final ExpressionList deleteItems;

	private final boolean detach;

	Delete(ExpressionList deleteItems, boolean detach) {
		this.deleteItems = deleteItems;
		this.detach = detach;
	}

	/**
	 * @return True, if the {@code DETACH} keyword needs to be included.
	 */
	@API(status = INTERNAL)
	public boolean isDetach() {
		return detach;
	}

	@Override
	public void accept(Visitor visitor) {
		visitor.enter(this);
		deleteItems.accept(visitor);
		visitor.leave(this);
	}
}

==> neo4j-cypher-dsl-2022.9.2-sources.jar: org/neo4j/cypherdsl/core/Delete.java <==
/*
 * Copyright (c) 2019-2024 "Neo4j,"
 * Neo4j Sweden AB [https://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.neo4j.cypherdsl.core;

import static org.apiguardian.api.API.Status.STABLE;
import static org.apiguardian.api.API.Status.INTERNAL;

import org.apiguardian.api.API;
import org.neo4j.cypherdsl.core.ast.Visitor;

/**
 * See <a href="https://s3.amazonaws.com/artifacts.opencypher.org/M15/railroad/Delete.html">Delete</a>.
 *
 * @author Michael J. Simons
 * @since 1.0
 */
@API(status = STABLE, since = "1.0")
public final class Delete implements UpdatingClause {

	private final ExpressionList deleteItems;

	private final boolean detach;

	Delete(ExpressionList deleteItems, boolean detach) {
		this.deleteItems = deleteItems;
		this.detach = detach;
	}

	/**
	 * @return True, if the {@code DETACH} keyword needs to be included.
	 */
	@API(status = INTERNAL)
	public boolean isDetach() {
		return detach;
	}

	@Override
	public void accept(Visitor visitor) {
		visitor.enter(this);
		deleteItems.accept(visitor);
		visitor.leave(this);
	}
}
